@@ -1,47 +1,47 @@
 {-# LANGUAGE ApplicativeDo   #-}
-{-# LANGUAGE QuasiQuotes     #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TupleSections   #-}
 
 {- |
-Copyright: (c) 2017-2019 Kowainik
-SPDX-License-Identifier: MPL-2.0
-Maintainer: Kowainik <xrom.xkov@gmail.com>
+Module                  : Summoner.CLI
+Copyright               : (c) 2017-2026 Kowainik
+SPDX-License-Identifier : MPL-2.0
+Maintainer              : Kowainik <xrom.xkov@gmail.com>
+Stability               : Stable
+Portability             : Portable
 
 This module contains functions and data types to parse CLI inputs.
 -}
 
 module Summoner.CLI
-       ( -- * CLI data types
-         Command (..)
-       , NewOpts (..)
-       , ShowOpts (..)
+    ( -- * CLI data types
+      Command (..)
+    , NewOpts (..)
+    , ShowOpts (..)
 
-         -- * Functions to parse CLI arguments and run @summoner@
-       , summon
-       , summonCli
+      -- * Functions to parse CLI arguments and run @summoner@
+    , summon
+    , summonCli
 
-         -- * Runners
-       , runConfig
-       , runScript
+      -- * Runners
+    , runConfig
+    , runScript
 
-         -- * Common helper functions
-       , getFinalConfig
-       , getCustomLicenseText
-       ) where
+      -- * Common helper functions
+    , getFinalConfig
+    , getCustomLicenseText
+    ) where
 
 import Colourista (blue, bold, errorMessage, formatWith, infoMessage, successMessage,
                    warningMessage)
 import Data.Version (Version, showVersion)
 import Development.GitRev (gitCommitDate, gitHash)
-import NeatInterpolation (text)
 import Options.Applicative (Parser, ParserInfo, ParserPrefs, argument, command, customExecParser,
                             flag, fullDesc, help, helpLongEquals, helper, info, infoFooter,
                             infoHeader, infoOption, long, maybeReader, metavar, option, prefs,
                             progDesc, short, showDefault, showHelpOnEmpty, strArgument, strOption,
                             subparser, subparserInline, switch, value)
 import Options.Applicative.Help.Chunk (stringChunk)
-import Relude.Extra.Enum (universe)
 import System.Directory (doesFileExist)
 import System.Info (os)
 import Validation (Validation (..))
@@ -58,7 +58,6 @@ import Summoner.Mode (ConnectMode (..), Interactivity (..), isOffline)
 import Summoner.Project (generateProject)
 import Summoner.Settings (Tool, parseTool)
 import Summoner.Template.Script (scriptFile)
-import Summoner.Text (endLine)
 
 import qualified Data.Text as T
 import qualified Paths_summoner as Meta (version)
@@ -84,10 +83,10 @@ summonCli = summon Meta.version runCliCommand
 -- | Run 'summoner' with @CLI@ command
 runCliCommand :: Command -> IO ()
 runCliCommand = \case
-    New opts -> runNew opts
-    Script opts -> runScript opts
+    New opts      -> runNew opts
+    Script opts   -> runScript opts
     ShowInfo opts -> runShow opts
-    Config opts -> runConfig opts
+    Config opts   -> runConfig opts
 
 
 {- | Runs @config@ command
@@ -254,13 +253,13 @@ readFileConfig ignoreFile maybeFile = if ignoreFile then pure mempty else do
 -- | Represent all available commands
 data Command
     -- | @new@ command creates a new project
-    = New NewOpts
+    = New !NewOpts
     -- | @script@ command creates Haskell script
-    | Script ScriptOpts
+    | Script !ScriptOpts
     -- | @show@ command shows supported licenses or GHC versions
-    | ShowInfo ShowOpts
+    | ShowInfo !ShowOpts
     -- | @config@ command creates the TOML configuration file
-    | Config ConfigOpts
+    | Config !ConfigOpts
 
 -- | Options parsed with the @new@ command
 data NewOpts = NewOpts
@@ -282,7 +281,7 @@ data ScriptOpts = ScriptOpts
 -- | Commands parsed with @show@ command
 data ShowOpts
     = GhcList
-    | LicenseList (Maybe String)
+    | LicenseList !(Maybe String)
 
 -- | Options parsed with the @config@ command
 newtype ConfigOpts = ConfigOpts
@@ -424,7 +423,7 @@ targetsP d = do
     cExe       <- execP      d
     cTest      <- testP      d
     cBench     <- benchmarkP d
-    pure mempty
+    pure (mempty :: PartialConfig)
         { cGitHub    = cGitHub
         , cGhActions = cGhActions
         , cTravis    = cTravis
@@ -583,39 +582,39 @@ modifyFooter :: ParserInfo a -> ParserInfo a
 modifyFooter p = p {infoFooter = stringChunk $ toString artFooter}
 
 artHeader :: Text
-artHeader = [text|
-$endLine
-                                                   ___
-                                                 ╱  .  ╲
-                                                │╲_/│   │
-                                                │   │  ╱│
-  ___________________________________________________-' │
- ╱                                                      │
-╱   .-.                                                 │
-│  ╱   ╲                                                │
-│ │\_.  │ Summoner — tool for creating Haskell projects │
-│\│  │ ╱│                                               │
-│ `-_-' │                                              ╱
-│       │_____________________________________________╱
-│       │
- ╲     ╱
-  `-_-'
-|]
+artHeader = unlines
+    [ ""
+    , "                                                   ___"
+    , "                                                 ╱  .  ╲"
+    , "                                                │╲_/│   │"
+    , "                                                │   │  ╱│"
+    , "  ___________________________________________________-' │"
+    , " ╱                                                      │"
+    , "╱   .-.                                                 │"
+    , "│  ╱   ╲                                                │"
+    , "│ │\\_.  │ Summoner — tool for creating Haskell projects │"
+    , "│\\│  │ ╱│                                               │"
+    , "│ `-_-' │                                              ╱"
+    , "│       │_____________________________________________╱"
+    , "│       │"
+    , " ╲     ╱"
+    , "  `-_-'"
+    ]
 
 artFooter :: Text
-artFooter = [text|
-$endLine
-              , *   +
-           +      o   *             ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
-            * @ ╭─╮  .      ________┃                                 ┃_______
-           ╱| . │λ│ @   '   ╲       ┃   λ Haskell's summon scroll λ   ┃      ╱
-         _╱ ╰─  ╰╥╯    O     ╲      ┃                                 ┃     ╱
-        .─╲"╱. * ║  +        ╱      ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛     ╲
-       ╱  ( ) ╲_ ║          ╱__________)                           (_________╲
-       ╲ ╲(')╲__(╱
-       ╱╱`)╱ `╮  ║
- `╲.  ╱╱  (   │  ║
-  ╲.╲╱        │  ║
-  `╰══════════╯
-$endLine
-|]
+artFooter = unlines
+    [ ""
+    , "              , *   +"
+    , "           +      o   *             ┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓"
+    , "            * @ ╭─╮  .      ________┃                                 ┃_______"
+    , "           ╱| . │λ│ @   '   ╲       ┃   λ Haskell's summon scroll λ   ┃      ╱"
+    , "         _╱ ╰─  ╰╥╯    O     ╲      ┃                                 ┃     ╱"
+    , "        .─╲\"╱. * ║  +        ╱      ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛     ╲"
+    , "       ╱  ( ) ╲_ ║          ╱__________)                           (_________╲"
+    , "       ╲ ╲(')╲__(╱"
+    , "       ╱╱`)╱ `╮  ║"
+    , " `╲.  ╱╱  (   │  ║"
+    , "  ╲.╲╱        │  ║"
+    , "  `╰══════════╯"
+    , ""
+    ]
