@@ -1,28 +1,28 @@
 {- |
-Copyright: (c) 2017-2019 Kowainik
-SPDX-License-Identifier: MPL-2.0
-Maintainer: Kowainik <xrom.xkov@gmail.com>
+Module                  : Summoner.GhcVer
+Copyright               : (c) 2017-2026 Kowainik
+SPDX-License-Identifier : MPL-2.0
+Maintainer              : Kowainik <xrom.xkov@gmail.com>
+Stability               : Stable
+Portability             : Portable
 
 Contains data type for GHC versions supported by Summoner
 and some useful functions for manipulation with them.
 -}
 
 module Summoner.GhcVer
-       ( GhcVer (..)
-       , GhcMeta (..)
-       , Pvp (..)
-       , showGhcVer
-       , parseGhcVer
-       , latestLts
-       , baseVer
-       , cabalBaseVersions
-       , ghcTable
+    ( GhcVer (..)
+    , GhcMeta (..)
+    , Pvp (..)
+    , showGhcVer
+    , parseGhcVer
+    , latestLts
+    , baseVer
+    , cabalBaseVersions
+    , ghcTable
 
-       , oldGhcs
-       ) where
-
-import Data.List (maximum, minimum)
-import Relude.Extra.Enum (inverseMap, universe)
+    , oldGhcs
+    ) where
 
 import qualified Data.Text as T
 import qualified Text.Show as Show
@@ -30,23 +30,37 @@ import qualified Text.Show as Show
 
 -- | Represents some selected set of GHC versions.
 data GhcVer
-    = Ghc7103
-    | Ghc802
+    = Ghc802
     | Ghc822
     | Ghc844
     | Ghc865
-    | Ghc883
+    | Ghc884
+    | Ghc8107
+    | Ghc902
+    | Ghc928
+    | Ghc948
+    | Ghc967
+    | Ghc984
+    | Ghc9103
+    | Ghc9123
     deriving stock (Eq, Ord, Show, Enum, Bounded)
 
 -- | Converts 'GhcVer' into dot-separated string.
 showGhcVer :: GhcVer -> Text
 showGhcVer = \case
-    Ghc7103 -> "7.10.3"
     Ghc802  -> "8.0.2"
     Ghc822  -> "8.2.2"
     Ghc844  -> "8.4.4"
     Ghc865  -> "8.6.5"
-    Ghc883  -> "8.8.3"
+    Ghc884  -> "8.8.4"
+    Ghc8107 -> "8.10.7"
+    Ghc902  -> "9.0.2"
+    Ghc928  -> "9.2.8"
+    Ghc948  -> "9.4.8"
+    Ghc967  -> "9.6.7"
+    Ghc984  -> "9.8.4"
+    Ghc9103 -> "9.10.3"
+    Ghc9123 -> "9.12.3"
 
 {- | These are old GHC versions that are not working with default GHC versions
 when using Stack.
@@ -60,19 +74,26 @@ parseGhcVer = inverseMap showGhcVer
 -- | Returns latest known LTS resolver for all GHC versions except default one.
 latestLts :: GhcVer -> Text
 latestLts = \case
-    Ghc7103 -> "lts-6.35"
     Ghc802  -> "lts-9.21"
     Ghc822  -> "lts-11.22"
     Ghc844  -> "lts-12.26"
     Ghc865  -> "lts-14.27"
-    Ghc883  -> "lts-15.5"
+    Ghc884  -> "lts-16.31"
+    Ghc8107 -> "lts-18.28"
+    Ghc902  -> "lts-19.33"
+    Ghc928  -> "lts-20.26"
+    Ghc948  -> "lts-21.25"
+    Ghc967  -> "lts-22.44"
+    Ghc984  -> "lts-23.28"
+    Ghc9103 -> "lts-24.26"
+    Ghc9123 -> "nightly-2026-01-04"
 
 -- | Represents PVP versioning (4 numbers).
 data Pvp = Pvp
-    { pvpFirst  :: Int
-    , pvpSecond :: Int
-    , pvpThird  :: Int
-    , pvpFourth :: Int
+    { pvpFirst  :: !Int
+    , pvpSecond :: !Int
+    , pvpThird  :: !Int
+    , pvpFourth :: !Int
     }
 
 -- | Show PVP version in a standard way: @1.2.3.4@
@@ -82,12 +103,19 @@ instance Show Pvp where
 -- | Returns base version by 'GhcVer' as 'Pvp'.
 baseVerPvp :: GhcVer -> Pvp
 baseVerPvp = \case
-    Ghc7103 -> Pvp 4 8 0 2
     Ghc802  -> Pvp 4 9 1 0
     Ghc822  -> Pvp 4 10 1 0
     Ghc844  -> Pvp 4 11 1 0
     Ghc865  -> Pvp 4 12 0 0
-    Ghc883  -> Pvp 4 13 0 0
+    Ghc884  -> Pvp 4 13 0 0
+    Ghc8107 -> Pvp 4 14 3 0
+    Ghc902  -> Pvp 4 15 1 0
+    Ghc928  -> Pvp 4 16 4 0
+    Ghc948  -> Pvp 4 17 2 1
+    Ghc967  -> Pvp 4 18 3 1
+    Ghc984  -> Pvp 4 19 2 0
+    Ghc9103 -> Pvp 4 20 2 0
+    Ghc9123 -> Pvp 4 21 1 0
 
 -- | Returns corresponding @base@ version of the given GHC version.
 baseVer :: GhcVer -> Text
@@ -103,12 +131,13 @@ baseVer = show . baseVerPvp
 
 -}
 cabalBaseVersions :: [GhcVer] -> Text
-cabalBaseVersions []   = ""
-cabalBaseVersions [v]  = "^>= " <> baseVer v
-cabalBaseVersions ghcs = ">= " <> baseVer (minimum ghcs) <> " && < " <> upperBound
+cabalBaseVersions ghcVers = case sort ghcVers of
+    []          -> ""
+    [v]         -> "^>= " <> baseVer v
+    minGhc:x:xs -> ">= " <> baseVer minGhc <> " && < " <> upperBound (x :| xs)
   where
-    upperBound :: Text
-    upperBound = let Pvp{..} = baseVerPvp $ maximum ghcs in
+    upperBound :: NonEmpty GhcVer -> Text
+    upperBound ghcs = let Pvp{..} = baseVerPvp $ last ghcs in
         show pvpFirst <> "." <> show (pvpSecond + 1)
 
 -- | Data type to keep meta information for every 'GhcVer'.
