@@ -1,13 +1,20 @@
-{-# LANGUAGE QuasiQuotes #-}
+{- |
+Module                  : Summoner.Template.Stack
+Copyright               : (c) 2017-2026 Kowainik
+SPDX-License-Identifier : MPL-2.0
+Maintainer              : Kowainik <xrom.xkov@gmail.com>
+Stability               : Stable
+Portability             : Portable
+
+Templates for @stack.yaml@ files.
+-}
 
 module Summoner.Template.Stack
        ( stackFiles
        ) where
 
-import NeatInterpolation (text)
-
 import Summoner.Default (defaultGHC)
-import Summoner.GhcVer (GhcVer (..), baseVer, latestLts, showGhcVer)
+import Summoner.GhcVer (GhcVer (..), latestLts, showGhcVer)
 import Summoner.Settings (Settings (..))
 import Summoner.Tree (TreeFs (..))
 
@@ -18,23 +25,9 @@ stackFiles Settings{..} = map createStackYaml settingsTestedVersions
     -- create @stack.yaml@ file with LTS corresponding to specified ghc version
     createStackYaml :: GhcVer -> TreeFs
     createStackYaml ghcV = File (toString $ "stack" <> ver <> ".yaml")
-        $ "resolver: lts-" <> latestLts ghcV <> extraDeps <> ghcOpts
+        $ "resolver: " <> latestLts ghcV <> "\n"
       where
         ver :: Text
         ver = if ghcV == defaultGHC
               then ""
               else "-" <> showGhcVer ghcV
-
-        extraDeps :: Text
-        extraDeps = case settingsPrelude of
-            Nothing -> ""
-            Just _  -> "\n\nextra-deps: [base-noprelude-" <> baseVer ghcV <> "]"
-
-        ghcOpts :: Text
-        ghcOpts = memptyIfFalse (ghcV > Ghc802)
-            [text|
-            $endLine
-
-            ghc-options:
-              "$$locals": -fhide-source-paths
-            |]
